@@ -108,13 +108,6 @@ void MainWindow::on_ditv_clicked()
     browser->show();
 }
 
-void MainWindow::on_kataweb_clicked()
-{
-    QProcess process;
-    process.start("sh /opt/serviziopubblico/script/kataweb.sh");
-    process.waitForFinished();
-}
-
 void MainWindow::on_rtv_clicked()
 {
     QProcess process;
