@@ -264,3 +264,17 @@ void PuntateMain::on_stream16_clicked()
     process.start("sh /opt/serviziopubblico/script/p16.sh");
     process.waitForFinished();
 }
+
+void PuntateMain::on_down17_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/d17.sh");
+    process.waitForFinished();
+}
+
+void PuntateMain::on_stream17_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/p17.sh");
+    process.waitForFinished();
+}
