@@ -84,6 +84,10 @@ private slots:
 
     void on_stream16_clicked();
 
+    void on_down17_clicked();
+
+    void on_stream17_clicked();
+
 private:
     Ui::PuntateMain *ui;
 };
